@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
 
 package Tickit::RenderBuffer;
 
@@ -10,7 +10,7 @@ use warnings;
 use feature qw( switch );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use Carp;
 use Scalar::Util qw( refaddr );
@@ -581,11 +581,6 @@ sub get_cell
    }
 }
 
-sub flush_to_window
-{
-   croak "Tickit::RenderBuffer->flush_to_window has been removed";
-}
-
 =head2 $rb->flush_to_term( $term )
 
 Renders the stored content to the given L<Tickit::Term>. After this, the
