@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use 5.010; # //
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use Carp;
 
@@ -1056,6 +1056,7 @@ sub set_expose_after_scroll
 {
    my $self = shift;
    ( $self->{expose_after_scroll} ) = @_;
+   warn "Disabling expose_after_scroll is now deprecated" if !$self->{expose_after_scroll};
 }
 
 =head2 $top = $win->top
@@ -1322,26 +1323,6 @@ sub _get_span_visibility
    return ( $vis, $len );
 }
 
-sub goto
-{
-   croak "Tickit::Window direct drawing methods have been removed; use the RenderBuffer instead";
-}
-
-sub print
-{
-   croak "Tickit::Window direct drawing methods have been removed; use the RenderBuffer instead";
-}
-
-sub erasech
-{
-   croak "Tickit::Window direct drawing methods have been removed; use the RenderBuffer instead";
-}
-
-sub clearrect
-{
-   croak "Tickit::Window direct drawing methods have been removed; use the RenderBuffer instead";
-}
-
 =head2 $success = $win->scrollrect( $rect, $downward, $rightward )
 
 =head2 $success = $win->scrollrect( $top, $left, $lines, $cols, $downward, $rightward )
